@@ -1,8 +1,8 @@
 from typing import Any, Dict
 
-from spark_auto_mapper.automapper import AutoMapper
-from spark_auto_mapper.automapper_base import AutoMapperBase
-from spark_auto_mapper.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.automappers.automapper_base import AutoMapperBase
+from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
 def mapping(parameters: Dict[str, Any]) -> AutoMapperBase:
@@ -12,18 +12,19 @@ def mapping(parameters: Dict[str, Any]) -> AutoMapperBase:
         view=parameters["view"],
         source_view="patients",
         keys=["member_id"]
-    ).withColumn(
-        dst_column="dst1",
-        value="src1"
-    ).withColumn(
-        dst_column="dst2",
-        value=A.list(
+    ).columns(
+        dst1="src1",
+        dst2=A.list(
             client_address_variable
-        )
-    ).withColumn(
-        dst_column="dst3",
-        value=A.list(
+        ),
+        dst3=A.list(
             [client_address_variable, "address2"]
+        ),
+        dst4=A.list(
+            A.complex(
+                use="usual",
+                family=A.column("last_name")
+            )
         )
     )
 
@@ -31,8 +32,7 @@ def mapping(parameters: Dict[str, Any]) -> AutoMapperBase:
 
     if company_name == "Microsoft":
         mapper = mapper.withColumn(
-            dst_column="dst4",
-            value=A.list(
+            dst4=A.list(
                 value=A.complex(
                     use="usual",
                     family=A.column("last_name")
